@@ -32,12 +32,12 @@ cleanup_devices()
 	for i in `seq $ndevs`; do
 		truncate -s0 img$i
 	done
-	run_check $SUDO_HELPER losetup --list
+	run_check $SUDO_HELPER losetup --all
 }
 
 test_get_info()
 {
-	run_check $TOP/btrfs inspect-internal dump-super $dev1
+	run_check $SUDO_HELPER $TOP/btrfs inspect-internal dump-super $dev1
 	run_check $SUDO_HELPER $TOP/btrfs check $dev1
 	run_check $SUDO_HELPER mount $dev1 $TEST_MNT
 	run_check $TOP/btrfs filesystem df $TEST_MNT
